
# q-expansion of newform 819.2.j.j, downloaded from the LMFDB on 10 February 2025.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 819
weight = 2
poly_data = [3969, 0, 15309, 0, 42354, 0, 50535, 0, 42361, 0, 20465, 0, 7087, 0, 1450, 0, 214, 0, 18, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[4100464099743309, 0, -381756166403724, 0, -1038664753795161, 0, -1700292246233089, 0, -897824477273942, 0, -364388612617081, 0, -78387283430809, 0, -12404989720237, 0, -1071726339501, 0, -63483510895, 0], 1162959409673433], [[4074076519121322, 0, 33916074886936899, 0, 37240214930441792, 0, 34908763903313215, 0, 17350266439406018, 0, 6342972032812640, 0, 1323203222713391, 0, 200600097872859, 0, 17059537295177, 0, 972440103969, 0], 8140715867714031], [[0, -12214792386835353, 0, -33916074886936899, 0, -37240214930441792, 0, -34908763903313215, 0, -17350266439406018, 0, -6342972032812640, 0, -1323203222713391, 0, -200600097872859, 0, -17059537295177, 0, -972440103969], 8140715867714031], [[0, -391940661381560172, 0, -1055208534594185970, 0, -1657884460666364181, 0, -820662585402724832, 0, -281019052814744494, 0, -19694815271066966, 0, 2415418960857382, 0, 1620001734899830, 0, 183416141110176, 0, 15906241212796], 122110738015710465], [[0, -673210607805901557, 0, -1855738713204194985, 0, -2471853241719180591, 0, -1801500577566755287, 0, -843493260538019684, 0, -272855589451486771, 0, -54575502056655373, 0, -7760971911815785, 0, -643881681068694, 0, -34329053073829], 244221476031420930], [[-1035184171252870674, 0, -1673228956511236221, 0, -1847826773857965204, 0, -504033320716439471, 0, -63109028620241428, 0, 83114472891063886, 0, 25531830021272647, 0, 5432306787565372, 0, 518705271356931, 0, 36362255678023, 0], 244221476031420930], [[-20843318495191563, 0, -46193115090254985, 0, -218500347312058479, 0, 46214339530770307, 0, 67782366155282234, 0, 54173268205538341, 0, 13592995182643123, 0, 2503616734276015, 0, 228809603427294, 0, 14981283821149, 0], 81407158677140310], [[-956134153778064912, 0, -1362017076273983925, 0, -1128557945938310376, 0, 164303017403277013, 0, 317654638581751046, 0, 198404754539328244, 0, 48047178162388507, 0, 8282283888015370, 0, 742171850598621, 0, 45939561634201, 0], 244221476031420930], [[0, -697280987541723606, 0, -1913788218560900985, 0, -2566060560557866758, 0, -1790734383482257936, 0, -804439232316677687, 0, -237382512305117863, 0, -45261824841434989, 0, -6015909322422085, 0, -481739104565112, 0, -23730211055842], 122110738015710465], [[0, -44833257710760717, 0, 42658395343767252, 0, 116063015076941103, 0, 182276409811617302, 0, 100325167925013466, 0, 40717701149973263, 0, 8782853949641036, 0, 1386164788656251, 0, 119757399916923, 0, 7070517816554], 34888782290202990], [[8085141923224617, 0, 25613946349825428, 0, 69689256180943167, 0, 100798666533840688, 0, 60239571790268474, 0, 24448669584005407, 0, 5326237879065424, 0, 832313317051339, 0, 71907524691147, 0, 4167081224956, 0], 11629594096734330], [[-1080729171108122193, 0, -4126185204528172734, 0, -5944562226654321237, 0, -4857403635645836986, 0, -2311154640108449636, 0, -759788932660048567, 0, -152003627330357230, 0, -21734972165437927, 0, -1801780008548685, 0, -96954046827562, 0], 244221476031420930], [[-44999554774688451, 0, -124851290515207497, 0, -141690206445201041, 0, -127733009889621237, 0, -63116294416706478, 0, -22821167842930993, 0, -4744101906837901, 0, -715565463449777, 0, -60736064804201, 0, -3445375839611, 0], 8140715867714031], [[-1111638429111283857, 0, -4321298074052013030, 0, -6475416416896603731, 0, -5547272361934548172, 0, -2770026363753126104, 0, -946025368601050741, 0, -193146329901913858, 0, -28075074444675325, 0, -2349531740797539, 0, -127729036819714, 0], 244221476031420930], [[0, -42625453567677741, 0, 56595028881184416, 0, 153981171522818424, 0, 231552747403668101, 0, 133101719613918928, 0, 54020303717187704, 0, 11721618419037938, 0, 1839029237173208, 0, 158882523648984, 0, 9268731387422], 17444391145101495], [[0, 139021197354030366, 0, -62321371377240276, 0, -169561142829745839, 0, -257057131097164436, 0, -146569086773028058, 0, -59486132906443919, 0, -12897427670500073, 0, -2025104082976763, 0, -174958418741499, 0, -10220984050847], 17444391145101495], [[0, -8081111827460457, 0, 73686750734038932, 0, 200483548255762623, 0, 291612542298620482, 0, 173298493336814906, 0, 70334457518209183, 0, 15319548262815556, 0, 2394416818422091, 0, 206865110727243, 0, 11984094316579], 17444391145101495], [[0, 1738718080767110961, 0, 4804039822897120410, 0, 5808620105149136133, 0, 4753992448925972941, 0, 2271691641749455397, 0, 769989190933461958, 0, 156119450125405234, 0, 22767394210354510, 0, 1904566195483437, 0, 104584051769077], 122110738015710465]]

hecke_ring_character_values = [[92, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [703, [0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [379, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0], [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, -1, 0, 0], [0, 0, 0, 1, 0, 0, 0, 1, 1, -1, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 1, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 1], [0, -1, 0, 0, -1, -1, -1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 0], [0, 0, 0, 0, 0, 0, 0, 0, -1, -1, 0, 0, 0, 0, 1, -1, 0, 0, 0, 0], [0, 0, 1, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0], [0, 1, 0, 0, 1, 0, 2, 0, 0, 0, 0, -2, 0, 0, 0, 0, 0, 1, 0, -1], [4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 0, -1, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2, 0, 0, 0, 0, 0, 0, 0, 0, -1], [0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 1, -1, 0, 0], [0, 0, 0, -3, 0, 0, 0, -1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-1, 0, 0, -1, 0, 0, 0, 2, 0, -3, 0, 0, 0, 2, -1, -3, 0, 0, 0, 0], [0, -2, 0, 0, -2, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 1, -1, 0, 1], [-2, 0, 0, -2, 0, 0, 0, 0, -1, 1, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0], [0, 0, -1, 4, 0, 0, 0, 1, -1, -2, 0, 0, 1, 1, -1, 1, 0, 0, 0, 0], [0, -1, 0, 0, -1, 1, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 1, 2, -1, -2], [0, 0, 0, 0, 4, -1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1], [3, 0, -3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 2, 0, -2, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2, 0, 0, 0, 0, 1, 2, 0, 0], [0, 0, 1, -1, 0, 0, 0, 1, 4, -1, 0, 0, -4, 0, 1, 0, 0, 0, 0, 0], [0, 0, 0, 0, -2, -1, 2, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, -3], [-3, 0, 0, -3, 0, 0, 0, 0, 3, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0], [0, 4, 0, 0, 4, -2, 1, 0, 0, 0, 3, -1, 0, 0, 0, 0, -3, 0, 2, 0], [9, 0, 0, 0, 0, 0, 0, -1, 0, -1, 0, 0, -3, 1, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 5, -1, -2, 0, 0, 0, -2, 0, 0, 0, 0, 0, 0, 0, 0, 2], [0, -2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 3, -1, 0], [2, 0, -3, 0, 0, 0, 0, -3, 0, -3, 0, 0, 3, 3, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, -4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2], [0, 0, 0, 0, 0, 0, 0, 4, 1, 0, 0, 0, 0, 4, 1, 0, 0, 0, 0, 0], [3, 0, 0, 3, 0, 0, 0, 2, 1, -3, 0, 0, 0, 2, 3, -3, 0, 0, 0, 0], [0, 0, 1, 7, 0, 0, 0, 0, 0, -1, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0], [0, 1, 0, 0, 1, -2, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, -1, 2, 2, -2], [0, 0, 0, 0, 3, 3, 1, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, -3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 3, 2, 1, 0], [-12, 0, 0, 0, 0, 0, 0, -1, 0, -1, 0, 0, 3, 1, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 2, -2, -2, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, -2], [-3, 0, 0, -3, 0, 0, 0, 0, -1, 3, 0, 0, 0, 0, 2, 3, 0, 0, 0, 0], [0, 1, 0, 0, 1, -2, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, -4, -1, 2, 1], [6, 0, 0, 6, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 5, 0, 0, 0, 0, 0], [5, 0, 3, 0, 0, 0, 0, -2, 0, -2, 0, 0, 4, 1, 0, 1, 0, 0, 0, 0], [-6, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, -4, -3, 0, 2, 0, 0, 0, 0], [0, -2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, -2, -2, -2, 0], [0, 0, 1, 7, 0, 0, 0, -3, -2, -1, 0, 0, 2, 4, 1, 4, 0, 0, 0, 0], [0, 0, 0, 0, -7, 2, 1, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, -3], [0, 1, 0, 0, 1, 1, -4, 0, 0, 0, -2, 4, 0, 0, 0, 0, 2, -1, -1, 1], [-7, 0, 0, -7, 0, 0, 0, -1, -3, 4, 0, 0, 0, -1, 0, 4, 0, 0, 0, 0], [0, 2, 0, 0, 2, -2, 2, 0, 0, 0, 1, -2, 0, 0, 0, 0, -1, 0, 2, 0], [0, 0, 0, 0, -3, -1, -2, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, -4], [0, -3, 0, 0, 0, 0, 0, 0, 0, 0, 0, -6, 0, 0, 0, 0, -4, 2, -1, 0], [0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, -2, 2, 0, 0], [0, 0, 6, 12, 0, 0, 0, -4, -4, 1, 0, 0, 4, 3, 6, 3, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 2, 4, 0, 0, 0, 0, 3, 4, 0, 0, 0, 0], [0, -8, 0, 0, -8, 1, 2, 0, 0, 0, 3, -2, 0, 0, 0, 0, -3, 3, -1, -3], [-5, 0, 0, -5, 0, 0, 0, -2, 3, -5, 0, 0, 0, -2, 0, -5, 0, 0, 0, 0], [0, 3, 0, 0, 3, 4, 0, 0, 0, 0, -2, 0, 0, 0, 0, 0, 2, -5, -4, 5], [-9, 0, 0, 0, 0, 0, 0, -4, 0, -4, 0, 0, 3, 4, 0, 0, 0, 0, 0, 0], [0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, -4, 0, 0, 0, 0, 1, 0, 3, 0], [0, 0, -2, 0, 0, 0, 0, 1, 6, 1, 0, 0, -6, -2, -2, -2, 0, 0, 0, 0], [0, 0, 0, 0, -3, 1, -2, 0, 0, 0, -2, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, -4, 5, 0, 0, 0, -1, 1, -2, 0, 0, -1, 3, -4, 3, 0, 0, 0, 0], [5, 0, 5, 0, 0, 0, 0, -1, 0, -1, 0, 0, -3, 3, 0, -2, 0, 0, 0, 0], [0, -4, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2, 0, 0, 0, 0, 2, -3, 1, 0], [-1, 0, -2, 0, 0, 0, 0, 3, 0, 3, 0, 0, -1, -1, 0, -2, 0, 0, 0, 0], [0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2, 0, 0, 0, 0, 0, -1, 2, 0], [0, 0, 0, 0, -4, 1, -6, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 5], [7, 0, 0, 7, 0, 0, 0, -1, -3, -2, 0, 0, 0, -1, 2, -2, 0, 0, 0, 0], [0, 0, -2, 1, 0, 0, 0, 4, -2, 0, 0, 0, 2, -4, -2, -4, 0, 0, 0, 0], [13, 0, 1, 0, 0, 0, 0, -2, 0, -2, 0, 0, -4, -2, 0, 4, 0, 0, 0, 0], [0, 0, 0, 0, -4, 1, 4, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, -5], [0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, -3, -7, -2, 0], [0, 0, -6, -1, 0, 0, 0, 6, 5, -3, 0, 0, -5, -3, -6, -3, 0, 0, 0, 0], [0, 0, 0, 0, -3, 0, 2, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 1], [-4, 0, 0, -4, 0, 0, 0, -5, 2, 5, 0, 0, 0, -5, 2, 5, 0, 0, 0, 0], [0, 3, 0, 0, 3, -2, 2, 0, 0, 0, 9, -2, 0, 0, 0, 0, -9, -1, 2, 1], [5, 0, -3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -3, 0, 3, 0, 0, 0, 0], [0, -3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 2, 1, 4, 0], [-12, 0, -3, 0, 0, 0, 0, 4, 0, 4, 0, 0, 2, 0, 0, -4, 0, 0, 0, 0], [0, 0, 3, 10, 0, 0, 0, 4, -3, -1, 0, 0, 3, -3, 3, -3, 0, 0, 0, 0], [0, 0, 0, 0, -5, -5, -4, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 4], [0, 1, 0, 0, 1, 1, -2, 0, 0, 0, -5, 2, 0, 0, 0, 0, 5, 2, -1, -2], [0, 0, 0, 5, 0, 0, 0, 0, 1, 3, 0, 0, -1, -3, 0, -3, 0, 0, 0, 0], [0, 5, 0, 0, 5, 1, 2, 0, 0, 0, -1, -2, 0, 0, 0, 0, 1, 2, -1, -2], [11, 0, -5, 0, 0, 0, 0, -2, 0, -2, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0], [0, 0, 0, 0, 0, -4, -4, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 2], [0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 1, -3, 0], [-15, 0, 0, -15, 0, 0, 0, -1, 3, -3, 0, 0, 0, -1, 0, -3, 0, 0, 0, 0], [0, 7, 0, 0, 7, 3, 2, 0, 0, 0, -3, -2, 0, 0, 0, 0, 3, 4, -3, -4], [0, 0, 0, 8, 0, 0, 0, 4, 10, -2, 0, 0, -10, -2, 0, -2, 0, 0, 0, 0], [0, -5, 0, 0, -5, 3, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, -6, 4, -3, -4], [0, 0, 0, 0, -3, 0, 2, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 3], [0, -11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, -2, -4, -1, 0], [0, 0, -4, -4, 0, 0, 0, 8, 0, -2, 0, 0, 0, -6, -4, -6, 0, 0, 0, 0], [0, 0, 5, -15, 0, 0, 0, -5, 0, 5, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0], [1, 0, 4, 0, 0, 0, 0, -5, 0, -5, 0, 0, 5, 7, 0, -2, 0, 0, 0, 0], [0, -7, 0, 0, 0, 0, 0, 0, 0, 0, 0, -4, 0, 0, 0, 0, -7, 5, 0, 0], [0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2, 0, 0, 0, 0, 1, 8, 1, 0], [0, 0, 0, 0, 8, -3, 1, 0, 0, 0, -3, 0, 0, 0, 0, 0, 0, 0, 0, -1], [-3, 0, 0, -3, 0, 0, 0, 1, 7, 0, 0, 0, 0, 1, -2, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, -5, 1, 6, 0, 0, 0, -5, 1, 6, 0, 0, 0, 0], [0, 4, 0, 0, 4, 5, -2, 0, 0, 0, -2, 2, 0, 0, 0, 0, 2, -2, -5, 2], [0, 0, 0, 0, -2, 0, -8, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 2], [0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 6, -5, 0, 0], [-14, 0, 3, 0, 0, 0, 0, 4, 0, 4, 0, 0, 0, -1, 0, -3, 0, 0, 0, 0], [0, 0, -2, 8, 0, 0, 0, 3, 2, -5, 0, 0, -2, 2, -2, 2, 0, 0, 0, 0], [-2, 0, 0, -2, 0, 0, 0, -7, -8, 3, 0, 0, 0, -7, -8, 3, 0, 0, 0, 0], [0, 7, 0, 0, 7, -2, -2, 0, 0, 0, -4, 2, 0, 0, 0, 0, 4, -5, 2, 5], [6, 0, 0, 6, 0, 0, 0, 0, -7, 5, 0, 0, 0, 0, 1, 5, 0, 0, 0, 0], [-10, 0, -2, 0, 0, 0, 0, -4, 0, -4, 0, 0, 4, 1, 0, 3, 0, 0, 0, 0], [0, -9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 4, -2, -1, 0], [5, 0, 2, 0, 0, 0, 0, 2, 0, 2, 0, 0, -3, -6, 0, 4, 0, 0, 0, 0], [0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 3, -2, 0], [0, 0, 0, 0, -7, 0, -8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5], [0, 2, 0, 0, 2, 0, -2, 0, 0, 0, -4, 2, 0, 0, 0, 0, 4, 0, 0, 0], [4, 0, 0, 4, 0, 0, 0, 0, 8, 2, 0, 0, 0, 0, 2, 2, 0, 0, 0, 0], [7, 0, 1, 0, 0, 0, 0, 10, 0, 10, 0, 0, -4, -5, 0, -5, 0, 0, 0, 0], [0, 0, 0, 0, -8, -2, -1, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, -9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, -2, -6, 1, 0], [0, 0, 4, -1, 0, 0, 0, 0, 7, -2, 0, 0, -7, 2, 4, 2, 0, 0, 0, 0], [0, 4, 0, 0, 4, 4, -4, 0, 0, 0, -2, 4, 0, 0, 0, 0, 2, -4, -4, 4], [0, 0, 3, 0, 0, 0, 0, -3, -5, 2, 0, 0, 5, 1, 3, 1, 0, 0, 0, 0], [0, 0, 0, 0, 13, -5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4], [7, 0, -12, 0, 0, 0, 0, -3, 0, -3, 0, 0, -1, 4, 0, -1, 0, 0, 0, 0], [0, 0, -3, 19, 0, 0, 0, 3, -8, 1, 0, 0, 8, -4, -3, -4, 0, 0, 0, 0], [-3, 0, 0, -3, 0, 0, 0, -1, -1, 6, 0, 0, 0, -1, 0, 6, 0, 0, 0, 0], [0, 7, 0, 0, 7, 1, 0, 0, 0, 0, -10, 0, 0, 0, 0, 0, 10, 1, -1, -1], [0, 0, 3, 9, 0, 0, 0, 3, 0, -1, 0, 0, 0, -2, 3, -2, 0, 0, 0, 0], [-8, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2, -9, 0, 9, 0, 0, 0, 0], [0, 0, 0, 0, -1, -1, 8, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, -4], [-8, 0, -2, 0, 0, 0, 0, 2, 0, 2, 0, 0, 0, 5, 0, -7, 0, 0, 0, 0], [0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, -8, -1, 6, 0], [28, 0, 0, 28, 0, 0, 0, 3, 3, -1, 0, 0, 0, 3, 5, -1, 0, 0, 0, 0], [0, -10, 0, 0, -10, 3, -2, 0, 0, 0, -3, 2, 0, 0, 0, 0, 3, -1, -3, 1], [0, -5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, -2, -2, -5, 0], [21, 0, -2, 0, 0, 0, 0, 1, 0, 1, 0, 0, 7, -1, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, -5, -3, 6, 0, 0, 0, -4, 0, 0, 0, 0, 0, 0, 0, 0, -4], [-7, 0, 0, -7, 0, 0, 0, 6, 4, -6, 0, 0, 0, 6, -5, -6, 0, 0, 0, 0], [0, -5, 0, 0, -5, -1, 0, 0, 0, 0, 9, 0, 0, 0, 0, 0, -9, -1, 1, 1], [-7, 0, 0, -7, 0, 0, 0, -5, 3, 0, 0, 0, 0, -5, -3, 0, 0, 0, 0, 0], [0, -2, 0, 0, -2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -5, 0, 5], [-7, 0, 4, 0, 0, 0, 0, 5, 0, 5, 0, 0, 1, -2, 0, -3, 0, 0, 0, 0], [0, -2, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, -1, 4, -6, 0], [0, 0, -6, 7, 0, 0, 0, -1, -9, 0, 0, 0, 9, 1, -6, 1, 0, 0, 0, 0], [0, 0, 0, 0, -1, 0, 8, 0, 0, 0, 9, 0, 0, 0, 0, 0, 0, 0, 0, -1], [0, 0, -3, -6, 0, 0, 0, 0, -5, -1, 0, 0, 5, 1, -3, 1, 0, 0, 0, 0], [0, -6, 0, 0, -6, 1, 2, 0, 0, 0, -3, -2, 0, 0, 0, 0, 3, -7, -1, 7], [21, 0, -6, 0, 0, 0, 0, 3, 0, 3, 0, 0, -5, -1, 0, -2, 0, 0, 0, 0], [0, 0, 0, 0, -6, 0, 2, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, -6], [-12, 0, 0, -12, 0, 0, 0, -1, 4, 1, 0, 0, 0, -1, 4, 1, 0, 0, 0, 0], [0, -10, 0, 0, -10, -2, 6, 0, 0, 0, 1, -6, 0, 0, 0, 0, -1, 0, 2, 0], [0, 0, 0, -9, 0, 0, 0, -6, -5, -1, 0, 0, 5, 7, 0, 7, 0, 0, 0, 0], [0, 0, 0, 0, 1, 2, 4, 0, 0, 0, 9, 0, 0, 0, 0, 0, 0, 0, 0, 5], [7, 0, -1, 0, 0, 0, 0, -1, 0, -1, 0, 0, -1, 1, 0, 0, 0, 0, 0, 0], [0, -8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 5, -8, -6, 0], [0, 0, 0, 0, -3, 0, 2, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, -6], [0, -8, 0, 0, -8, 1, -5, 0, 0, 0, -8, 5, 0, 0, 0, 0, 8, -1, -1, 1], [12, 0, -7, 0, 0, 0, 0, 6, 0, 6, 0, 0, -1, -6, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, -9, -2, -4, 0, 0, 0, -5, 0, 0, 0, 0, 0, 0, 0, 0, -3], [0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, -3, 6, 4, 0], [0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, -6, 0, 0, 0, 0, 0, -2, -6, 0], [-10, 0, 0, -10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -14, 0, 0, 0, 0, 0], [11, 0, 0, 11, 0, 0, 0, -2, 7, -3, 0, 0, 0, -2, 3, -3, 0, 0, 0, 0]]
